@@ -11,7 +11,7 @@ from dataquality.loggers.logger_config.text_classification import (
 from dataquality.loggers.model_logger.base_model_logger import BaseGalileoModelLogger
 from dataquality.schemas import __data_schema_version__
 from dataquality.schemas.split import Split
-from dataquality.utils.stdout_logger import get_stdout_logger
+from dataquality.utils.dq_logger import get_dq_logger
 
 
 @unique
@@ -108,7 +108,7 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
         * embs, probs, and ids must exist and be the same length
         :return:
         """
-        get_stdout_logger().info("Handling logits and probs", split=self.split)
+        get_dq_logger().info("Handling logits and probs", split=self.split)
         if len(self.logits):
             self.logits = self._convert_tensor_ndarray(self.logits, "Prob")
             self.probs = self.convert_logits_to_probs(self.logits)
@@ -121,11 +121,11 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
         probs_len = len(self.probs)
         ids_len = len(self.ids)
 
-        get_stdout_logger().info("Converting inputs to numpy arrays", split=self.split)
+        get_dq_logger().info("Converting inputs to numpy arrays", split=self.split)
         self.embs = self._convert_tensor_ndarray(self.embs, "Embedding")
         self.ids = self._convert_tensor_ndarray(self.ids)
 
-        get_stdout_logger().info("Validating embedding shape", split=self.split)
+        get_dq_logger().info("Validating embedding shape", split=self.split)
         assert self.embs.ndim == 2, "Only one embedding vector is allowed per input."
 
         assert embs_len and probs_len and ids_len, (
@@ -143,7 +143,7 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
         try:
             self.split = Split[self.split].value
         except KeyError:
-            get_stdout_logger().error("Provided a bad split", split=self.split)
+            get_dq_logger().error("Provided a bad split", split=self.split)
             raise AssertionError(
                 f"Split should be one of {Split.get_valid_attributes()} "
                 f"but got {self.split}"
